<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="az">
<context>
    <name>main</name>
    <message>
        <source>Indicator Style</source>
        <translation>نوع المؤشر</translation>
    </message>
    <message>
        <source>Fashion Mode</source>
        <translation>الMode الموضوي</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>الMode الفعال</translation>
    </message>
    <message>
        <source>Classic Mode</source>
        <translation>الوضع الكلاسيكي</translation>
    </message>
    <message>
        <source>Centered Mode</source>
        <translation>الوضع المركزي</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>يسار</translation>
    </message>
    <message>
        <source>Position</source>
        <translation>الposição</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>الMode</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>أعلى</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>أسفل</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>يمين</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>الحالة</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>احفظ العرض</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>احفظ الخفاء</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>إخفاء ذكي</translation>
    </message>
    <message>
        <source>Dock Settings</source>
        <translation>إعدادات الرف</translation>
    </message>
    <message>
        <source>Lock the Dock</source>
        <translation>Dock-un kilidləməsi</translation>
    </message>
</context>
</TS>